"""
Модуль с описанием класса Configuration
"""
# TODO: Написать документацию по конфигу логирования
# from .handlers import DBHandler
from .configuration import Configuration

__version__ = '1.4.4'
__name__ = 'py-configuration-Orinnass'
